@@ -3,7 +3,6 @@ from ddd_objects.domain.entity import Entity, ExpiredEntity
 from .value_obj import (
     ContainerArgs,
     ContainerCommand,
-    ContainerEnvDict,
     DNSPolicy,
     DockerImageName,
     EnvVarSourceType,
@@ -662,16 +661,16 @@ class KeyToPath(Entity):
         self.path=path
         self.mode=mode
 
-class PodSecurityContext(Entity):
-    def __init__(
-        self,
-        run_as_user: Optional[Number] = None,
-        run_as_group: Optional[Number] = None,
-        run_as_non_root: Optional[Bool] = None
-    ):
-        self.run_as_user=run_as_user
-        self.run_as_group=run_as_group
-        self.run_as_non_root=run_as_non_root
+# class PodSecurityContext(Entity):
+#     def __init__(
+#         self,
+#         run_as_user: Optional[Number] = None,
+#         run_as_group: Optional[Number] = None,
+#         run_as_non_root: Optional[Bool] = None
+#     ):
+#         self.run_as_user=run_as_user
+#         self.run_as_group=run_as_group
+#         self.run_as_non_root=run_as_non_root
 
 class EnvVarSource(Entity):
     def __init__(
@@ -829,6 +828,17 @@ class LabelSelector(Entity):
         self.match_expressions = match_expressions
         self.match_labels=match_labels
 
+class SecurityContext(Entity):
+    def __init__(
+        self,
+        privileged: Optional[Bool] = None,
+        run_as_user: Optional[Number] = None,
+        run_as_non_root: Optional[Bool] = None
+    ):
+        self.privileged=privileged
+        self.run_as_user=run_as_user
+        self.run_as_non_root=run_as_non_root
+
 class ContainerSetting(Entity):
     def __init__(
         self,
@@ -840,7 +850,7 @@ class ContainerSetting(Entity):
         image_pull_policy: Optional[ImagePullPolicy]=ImagePullPolicy('Always'),
         working_dir: Optional[Path]=None,
         volume_mount: Optional[List[VolumeMount]]=None,
-        security_context: Optional[PodSecurityContext]=None,
+        security_context: Optional[SecurityContext]=None,
         limits: Optional[PodResourceDict]=None,
         requests: Optional[PodResourceDict]=None,
         readiness_probe: Optional[Probe]=None,
@@ -924,4 +934,5 @@ class PodLogSetting(Entity):
         self.namespace_name=namespace_name
         self.pod_name=pod_name
         self.container_name=container_name
-        self.tail_lines=tail_lines
\ No newline at end of file
+        self.tail_lines=tail_lines
+
