@@ -16,7 +16,7 @@ from ..domain.entity import (
     NodeInfo,
     NodeUserSetting,
     Pod,
-    PodSecurityContext,
+    PodLogSetting,
     Probe,
     SecretUserSetting,
     Namespace,
@@ -34,6 +34,7 @@ from ..domain.entity import (
     ConfigMapUserSetting,
     NodeMeta,
     CommandSetting,
+    SecurityContext,
     Service,
     InstanceTypeUserSetting,
     PodOSSOperationInfo,
@@ -47,6 +48,7 @@ from ..domain.value_obj import (
     ContainerCommand,
     EnvVarSourceType,
     HTTPHeader,
+    Integer,
     JobStatus,
     LabelSelectorOperator,
     MatchLabels,
@@ -122,7 +124,7 @@ from .do import (
     KeyToPathDO,
     LabelSelectorDO,
     LabelSelectorRequirementDO,
-    PodSecurityContextDO,
+    PodLogSettingDO,
     ProbeDO,
     SecretDO,
     NamespaceDO,
@@ -137,6 +139,7 @@ from .do import (
     ConfigMapDO,
     InstanceInfoDO,
     NodeInfoDO,
+    SecurityContextDO,
     ServiceDO,
     SecretUserSettingDO,
     PodDO,
@@ -762,20 +765,20 @@ class KeyToPathConverter(Converter):
         )
 key_to_path_converter = KeyToPathConverter()
 
-class PodSecurityContextConverter(Converter):
-    def to_entity(self, do: PodSecurityContextDO):
-        return PodSecurityContext(
-            run_as_user = Number(do.run_as_user),
-            run_as_group = Number(do.run_as_group),
-            run_as_non_root = Bool(do.run_as_non_root)
-        )
-    def to_do(self, x: PodSecurityContext):
-        return PodSecurityContextDO(
-            run_as_user = None if x.run_as_user is None else x.run_as_user.get_value(),
-            run_as_group = None if x.run_as_group is None else x.run_as_group.get_value(),
-            run_as_non_root = None if x.run_as_non_root is None else x.run_as_non_root.get_value()
-        )
-pod_security_context_converter = PodSecurityContextConverter()
+# class PodSecurityContextConverter(Converter):
+#     def to_entity(self, do: PodSecurityContextDO):
+#         return PodSecurityContext(
+#             run_as_user = Number(do.run_as_user),
+#             run_as_group = Number(do.run_as_group),
+#             run_as_non_root = Bool(do.run_as_non_root)
+#         )
+#     def to_do(self, x: PodSecurityContext):
+#         return PodSecurityContextDO(
+#             run_as_user = None if x.run_as_user is None else x.run_as_user.get_value(),
+#             run_as_group = None if x.run_as_group is None else x.run_as_group.get_value(),
+#             run_as_non_root = None if x.run_as_non_root is None else x.run_as_non_root.get_value()
+#         )
+# pod_security_context_converter = PodSecurityContextConverter()
 
 class EnvVarSourceConverter(Converter):
     def to_entity(self, do: EnvVarSourceDO):
@@ -981,6 +984,21 @@ class LabelSelectorConverter(Converter):
         )
 label_selector_converter =LabelSelectorConverter()
 
+class SecurityContextConverter(Converter):
+    def to_entity(self, do: SecurityContextDO):
+        return SecurityContext(
+            privileged = Bool(do.privileged),
+            run_as_user = Number(do.run_as_user),
+            run_as_non_root = Bool(do.run_as_non_root)
+        )
+    def to_do(self, x: SecurityContext):
+        return SecurityContextDO(
+            privileged = None if x.privileged is None else x.privileged.get_value(),
+            run_as_user = None if x.run_as_user is None else x.run_as_user.get_value(),
+            run_as_non_root = None if x.run_as_non_root is None else x.run_as_non_root.get_value()
+        )
+security_context_converter = SecurityContextConverter()
+
 class ContainerSettingConverter(Converter):
     def to_do(self, x: ContainerSetting):
         return ContainerSettingDO(
@@ -992,7 +1010,7 @@ class ContainerSettingConverter(Converter):
             image_pull_policy = None if x.image_pull_policy is None else x.image_pull_policy.get_value(),
             working_dir = None if x.working_dir is None else x.working_dir.get_value(),
             volume_mount = None if x.volume_mount is None else [volume_mount_converter.to_do(i) for i in x.volume_mount],
-            security_context = None if x.security_context is None else pod_security_context_converter.to_do(x.security_context),
+            security_context = None if x.security_context is None else security_context_converter.to_do(x.security_context),
             limits = None if x.limits is None else x.limits.get_value(),
             requests = None if x.requests is None else x.requests.get_value(),
             readiness_probe = None if x.readiness_probe is None else probe_converter.to_do(x.readiness_probe),
@@ -1038,4 +1056,21 @@ class JobConverter(Converter):
             status = None if x.status is None else x.status.get_value(),
             parallelism = None if x.parallelism is None else x.parallelism.get_value(),
             _life_time = None if x._life_time is None else x._life_time.get_value()
-        )
\ No newline at end of file
+        )
+
+class PodLogSettingConverter(Converter):
+    def to_entity(self, do: PodLogSettingDO):
+        return PodLogSetting(
+            namespace_name = Name(do.namespace_name),
+            pod_name = Name(do.pod_name),
+            container_name = None if do.container_name is None else Name(do.container_name),
+            tail_lines = Integer(do.tail_lines)
+        )
+    def to_do(self, x: PodLogSetting):
+        return PodLogSettingDO(
+            namespace_name = None if x.namespace_name is None else x.namespace_name.get_value(),
+            pod_name = None if x.pod_name is None else x.pod_name.get_value(),
+            container_name = None if x.container_name is None else x.container_name.get_value(),
+            tail_lines = None if x.tail_lines is None else x.tail_lines.get_value()
+        )
+
